@@ -1,16 +1,11 @@
-from __future__ import print_function
-from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
-from builtins import str
 import argparse
 import os
 import subprocess
-import urllib.request, urllib.error, urllib.parse
-from . import utils
+import urllib2
+import utils
 import sys
 from shutil import copyfile
-from .agent import run_agent
+from agent import run_agent
 from time import sleep
 
 
@@ -115,7 +110,7 @@ def handle_cloud_provider(cloud_provider, instance_details_path):
         os.chmod(full_path, 0o644)
         return True
     except IOError:
-        print("Unable to create /etc/spotinst/cloud_provider.txt")
+        print "Unable to create /etc/spotinst/cloud_provider.txt"
         if cloud_provider_file is not None:
             cloud_provider_file.close()
         return False
@@ -246,8 +241,8 @@ def install_collector(collector_name, modules_path, s3_base_collectors_link):
 
 
 def get_worker_files(modules_path, s3_base_workers_link, worker_name):
-    py_response = urllib.request.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.py')
-    yml_response = urllib.request.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.yml')
+    py_response = urllib2.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.py')
+    yml_response = urllib2.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.yml')
 
     with open(modules_path + '/' + worker_name + '.py', 'wb') as worker:
         worker.write(py_response.read())
@@ -257,16 +252,16 @@ def get_worker_files(modules_path, s3_base_workers_link, worker_name):
 
 def get_collector_files(collector_name, modules_path, s3_base_collectors_link):
     with open(modules_path + '/' + collector_name + '.py', 'wb') as collector:
-        response = urllib.request.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.py')
+        response = urllib2.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.py')
         collector.write(response.read())
     with open(modules_path + '/' + collector_name + '.yml', 'wb') as collector_cfg:
-        response = urllib.request.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.yml')
+        response = urllib2.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.yml')
         collector_cfg.write(response.read())
 
 
 def handle_prerequisites(s3_base_module_link, module_name):
     try:
-        response = urllib.request.urlopen(s3_base_module_link + '/' + module_name + '/' + module_name + '.req')
+        response = urllib2.urlopen(s3_base_module_link + '/' + module_name + '/' + module_name + '.req')
         requirements_file = response.read()
         requirements_names = requirements_file.split("\n")
         print ("This module requires the following packages to be installed:")
