@@ -1,6 +1,3 @@
-from __future__ import absolute_import
-from builtins import str
-from builtins import object
 import inspect
 import logging
 import os
@@ -8,9 +5,9 @@ import sys
 import time
 import traceback
 
-from .scheduler import ThreadedScheduler, method
-from .utils import load_class_from_name
-from . import basemodule
+from scheduler import ThreadedScheduler, method
+from utils import load_class_from_name
+import basemodule
 
 
 class TaskManager(object):
@@ -35,7 +32,7 @@ class TaskManager(object):
         modules = self.load_modules(modules_folder)
 
         # Setup Modules
-        for module in list(modules.values()):
+        for module in modules.values():
             # Initialize Module
             c = self.init_module(module['cls'])
             # Schedule Module
@@ -76,7 +73,7 @@ class TaskManager(object):
                 modules = self.load_modules(modules_folder)
 
                 # Setup Modules
-                for module in list(modules.values()):
+                for module in modules.values():
                     # Initialize Module
                     c = self.init_module(module['cls'])
                     # Schedule Module
@@ -124,7 +121,7 @@ class TaskManager(object):
                 mod_modification_time_str = str(mod_modification_time)
                 self.log.info("Py file found: %s" % modname)
 
-                modules_list = [x.lower() for x in list(self.tasks.keys())]
+                modules_list = [x.lower() for x in self.tasks.keys()]
                 if modname in modules_list:
                     if self.tasks[modname]['modification_time'] == mod_modification_time_str:
                         self.log.info("Module '{0}' already loaded".format(modname))
@@ -153,10 +150,9 @@ class TaskManager(object):
                 for attrname in dir(mod):
                     attr = getattr(mod, attrname)
                     # Only attempt to load classes that are infact classes but not the base Module class
-                    self.log.info("Checking " + str(modname) + " Attribute " + str(attrname))
-                    self.log.info(attr)
+                    self.log.debug("Checking " + str(modname) + " Attribute " + str(attrname))
 
-                    if inspect.isclass(attr) and isModule(attr) and attr != basemodule.Module and attrname != "Module":
+                    if inspect.isclass(attr) and isModule(attr) and attr != basemodule.Module:
                         # Get class name
                         fqcn = '.'.join([modname, attrname])
                         self.log.info("Module loaded : " + fqcn)
@@ -206,7 +202,7 @@ class TaskManager(object):
             return
 
         # Get Module schedule
-        for name, schedule in list(c.get_schedule().items()):
+        for name, schedule in c.get_schedule().items():
             # Get scheduler args
             func, args, splay, interval = schedule
 
@@ -237,7 +233,7 @@ class TaskManager(object):
 
         self.log.info('Stopped task scheduler.')
 
-        for key, task in self.tasks.items():
+        for key, task in self.tasks.iteritems():
             try:
                 self.scheduler.cancel(task['task'])
                 # Log
